@@ -88,9 +88,9 @@ def distribution(returns, compounded=True, prepare_returns=True):
     return {
         "Daily": get_outliers(daily),
         "Weekly": get_outliers(daily.resample("W-MON").apply(apply_fnc)),
-        "Monthly": get_outliers(daily.resample("M").apply(apply_fnc)),
+        "Monthly": get_outliers(daily.resample("ME").apply(apply_fnc)),
         "Quarterly": get_outliers(daily.resample("Q").apply(apply_fnc)),
-        "Yearly": get_outliers(daily.resample("A").apply(apply_fnc)),
+        "Yearly": get_outliers(daily.resample("YE").apply(apply_fnc)),
     }
 
 
@@ -102,7 +102,7 @@ def expected_return(returns, aggregate=None, compounded=True, prepare_returns=Tr
     if prepare_returns:
         returns = _utils._prepare_returns(returns)
     returns = _utils.aggregate_returns(returns, aggregate, compounded)
-    return _np.product(1 + returns) ** (1 / len(returns)) - 1
+    return _np.prod(1 + returns, axis=0) ** (1 / len(returns)) - 1
 
 
 def geometric_mean(retruns, aggregate=None, compounded=True):
@@ -951,6 +951,13 @@ def kelly_criterion(returns, prepare_returns=True):
 
     return ((win_loss_ratio * win_prob) - lose_prob) / win_loss_ratio
 
+# Calculate the correlation to the benchmark
+def benchmark_correlation(returns, benchmark, prepare_returns=True):
+    """Calculates the correlation to the benchmark"""
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
+    return returns.corrwith(_utils._prepare_benchmark(benchmark, returns.index))
+
 
 # ==== VS. BENCHMARK ====
 
@@ -959,6 +966,15 @@ def r_squared(returns, benchmark, prepare_returns=True):
     """Measures the straight line fit of the equity curve"""
     if prepare_returns:
         returns = _utils._prepare_returns(returns)
+
+    # Check if all returns index x values are identical to prevent the error ValueError: Cannot calculate a linear regression if all x values are identical
+    if len(_np.unique(_np.array(returns.index))) == 1:
+        return 0
+
+    # Check if all benchmark values are identical
+    if len(_np.unique(_np.array(benchmark))) == 1:
+        return 0
+
     _, _, r_val, _, _ = _linregress(
         returns, _utils._prepare_benchmark(benchmark, returns.index)
     )
@@ -1153,3 +1169,16 @@ def monthly_returns(returns, eoy=True, compounded=True, prepare_returns=True):
     returns.index.name = None
 
     return returns
+
+
+# Calculate the romad (return/cagr over max drawdown) of a strategy
+def romad(returns, periods=365, annualize=True, smart=False):
+    """
+    Calculates the romad (return/cagr over max drawdown) of a strategy
+    Args:
+        * returns (Series, DataFrame): Input return series
+        * periods (int): Freq. of returns
+        * annualize: return annualize sharpe?
+        * smart: return smart sharpe ratio
+    """
+    return cagr(returns, periods=periods) / -max_drawdown(returns)
